==> haskell-htf-0.15.0.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HTF
version:              0.15.0.2
visibility:           public
id:                   HTF-0.15.0.2-LMaw9ZCorRkL84FnebUVOJ
key:                  HTF-0.15.0.2-LMaw9ZCorRkL84FnebUVOJ
license:              LGPL-2.1-only
copyright:            (c) 2005-2024 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  4da8049d4cb82f1c2f6e40be7d666f05
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.2-LMaw9ZCorRkL84FnebUVOJ
depends:
    Diff-0.4.1-7Fwvr1SqYTt4uBZ7hvolZA
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-1roXk93057vCM76NaUaTTz
    aeson-2.1.2.1-HUj8Ou2Jrr19darX8iyQt4 array-0.5.4.0 base-4.17.2.1
    base64-bytestring-1.2.1.0-IbCUnYF5PxIJ57HxqijudZ
    bytestring-0.11.5.3 containers-0.6.7
    cpphs-1.20.9.1-KMTErBmnvc26XA8bncSIwV directory-1.3.7.1
    haskell-src-1.0.4.1-FvnCc7VacDL6jffMC49rMp
    lifted-base-0.2.3.12-8jv2OI8JOeaE6wsyLlY7lV
    monad-control-1.0.3.1-1muznQSV14KveEnsCnoJt mtl-2.2.2
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 pretty-1.1.3.6
    process-1.6.18.0 random-1.2.1.3-5GClgMcgHINEWJGyng3KHI
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8 text-2.0.2 time-1.12.2
    unix-2.7.3 vector-0.13.2.0-GDtmlcfK9QZ7E5AlTQVnIi
    xmlgen-0.6.2.2-ITATgYoOIM0Hqa5EYg6U6K

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-htf-0.15.0.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HTF
version:              0.15.0.2
visibility:           public
id:                   HTF-0.15.0.2-KzS7dApv08nHY96Ur1kZKj
key:                  HTF-0.15.0.2-KzS7dApv08nHY96Ur1kZKj
license:              LGPL-2.1-only
copyright:            (c) 2005-2024 Stefan Wehr
maintainer:           Stefan Wehr
author:               Stefan Wehr
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ directory in
    the HTF repo provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  461e943904ca098f9f25f387387665ce
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HTF-0.15.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.2-KzS7dApv08nHY96Ur1kZKj
depends:
    Diff-0.4.1-3XSAUTYqfoXJz3dVFogLZy
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-76HC5XzyauqDQFZ8BHcZeC
    aeson-2.1.2.1-7goQjQKasWuq7oOasot83 array-0.5.4.0 base-4.17.2.1
    base64-bytestring-1.2.1.0-ALlNDgCJ5uI9xkCg0LJBoH
    bytestring-0.11.5.3 containers-0.6.7
    cpphs-1.20.9.1-KMTErBmnvc26XA8bncSIwV directory-1.3.7.1
    haskell-src-1.0.4.1-8noERxk1uSC2AEdEunbbvV
    lifted-base-0.2.3.12-Cv5n8clpZ5K5QqXgJWMT4H
    monad-control-1.0.3.1-C6ihb2mA0cN3fEkZdc54bR mtl-2.2.2
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 pretty-1.1.3.6
    process-1.6.18.0 random-1.2.1.3-G8HhURP50mfDOIe4gICdYG
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8 text-2.0.2 time-1.12.2
    unix-2.7.3 vector-0.13.2.0-GjxrA8HCtQq4MGRlxeWifh
    xmlgen-0.6.2.2-8Q8nLvUvhsQ2HZuTPkxMqA

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
